#!/bin/sh
#
# Copyright (c) 2010, 2011  Peter Pentchev
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

set -e

usage()
{
	cat <<EOQ
Usage:	hostsearch [-hV] [-f hostsfile] pkgname...
	-f	specify the hosts list file, default int.hoster.bg.z
	-h	display program usage information and exit
	-V	display program version information and exit
EOQ
}

version()
{
	echo 'hostsearch 0.01'
}

zonefile='int.hoster.bg.z'
hflag=''
Vflag=''
while getopts 'f:hV' o; do
	case "$o" in
		f)
			zonefile="$OPTARG"
			;;
		h)
			hflag=1
			;;
		V)
			Vflag=1
			;;
		*)
			usage 1>&2
			exit 1
			;;
	esac
done

[ -z "$Vflag" ] || version
[ -z "$hflag" ] || usage
[ -z "$hflag$Vflag" ] || exit 0

shift `expr "$OPTIND" - 1`
if [ $# -lt 1 ]; then
	usage 1>&2
	exit 1
fi
pkg="$1"

if [ ! -r "$zonefile" ]; then
	echo "Missing or unreadable zone file '$zonefile'" 1>&2
	exit 1
fi
for i in `cat "$zonefile"`; do
	ssh $v "$i" dpkg -l "$@" 2>&1 | sed -ne '/^i/ { s@^@'"$i"' @; p; }'
done
